translate.tools.pocompile

Package translate :: Package tools :: Module pocompile |
[hide private]
[frames] | no frames]

# Module pocompile

source code

Compile XLIFF and Gettext PO localization files into Gettext MO (Machine Object) files

See: http://translate.sourceforge.net/wiki/toolkit/pocompile for examples and usage instructions

Classes | [hide private]
| POCompile

Functions | [hide private]
convertmo(inputfile, outputfile, templatefile, includefuzzy=False) reads in a base class derived inputfile, converts using pocompile, writes to outputfile | source code
main() | source code

Imports: factory, po, mo